<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Models\Chamber;
use App\Models\Unit;

use DB;

class ChambersController extends Controller
{
   /**
     *  Only authenticated users can access this controller
     */
    public function __construct(){
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $chambers = Chamber::Paginate(20);
        return view('chambers.index')->with('chambers',$chambers);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        /**
         *  Get Departments so we can show department
         *  name on the department dropdown in the view
         */
        $units = Unit::orderBy('unit_name','asc')->get();
        

     
        return view('chambers.create')->with([
            'units'  => $units,
            
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {   
        /**
         *  validateRequest is a method defined in this controller
         *  which will validate  the form. we have created 
         *  it so we can reuse it in the update method with 
         *  different parameters.
         */
        $this->validateRequest($request,null);
        
        /**
         *  Note!
         *  before using storage we need to link it to 
         *  the public folder by typing the command,
         *  php artisan storage:link  
         */

        /**
         * 
         *  Handle the image file upload which will be stored
         *  in storage/app/public/employee_images
         */


        /**
         *  Create new object of Employee
         */
        $chamber = new Chamber();
        
        /**
         *  setEmployee is also a method of this controller
         *  which i have created, so i can use it for update 
         *  method.
         */
        $this->setChamber($chamber,$request);
        
        return redirect('/chambers')->with('info','New Chamber has been created!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $chamber = Chamber::find($id);
        return view('chambers.show')->with('chamber',$chamber);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        /**
         *  this is same as create but with an existing
         *  employee
         */
        $units = Unit::orderBy('unit_name','asc')->get();

        $chamber = Chamber::find($id);
     
        return view('chambers.edit')->with([
            'units'  => $units,
            'chamber' => $chamber,
            
          
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $this->validateRequest($request,$id);
        $chamber = Chamber::find($id);
    
        $this->setChamber($chamber,$request);
        return redirect('/chambers')->with('info','Selected Chamber has been updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $chamber = Chamber::find($id);
        $chamber->delete();
        return redirect('/chambers')->with('info','Selected Chamber has been deleted!');
    }

    /**
     *  Search For Resource(s)
     * 
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function search(Request $request){
        $this->validate($request,[
            'search'   => 'required|min:1',
            'options'  => 'required'
        ]);
        $str = $request->input('search');
        $option = $request->input('options');
        $chambers = new Chamber();
        if($option == 'unit_name'){
            $units = Unit::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($units)){
        
                foreach($units as $unit) {
                    $u_id[] = $unit->id;
                   } 
                $unit_ids = implode(',',$u_id);
                // print_r($unit_ids);
                $chambers = Chamber::whereIn('unit_id' , [$unit_ids])
                ->paginate(20);
                // print_r($sales);
            }
        }
        else{
        $chambers = Chamber::where($option, 'LIKE' , '%'.$str.'%')->Paginate(4);
        }
        return view('chambers.index')->with(['chambers' => $chambers , 'search' => true ]);
    }

    /**
     * This method is used for validating the form
     *
     * @param  \Illuminate\Http\Request  $request
     * @return $this
     */
    private function validateRequest($request,$id){
        /**
         *  specifying the validation rules 
         */
        /**
         *  Below in Picture validation rules we are first checking
         *  that if there is an image, if not then don't apply the
         *  validation rules. the reason we are doing this is because
         *  if we are updating an employee but not updating the image. 
         */
        return $this->validate($request,[
            'chambers_name'     =>  'required|min:3|max:50',
            'dimension'      =>  '',
            'created_by'        =>  '',
            'updated_by'          =>  '',
            'unit'     =>  'required',
         
         
            
        ]);
    }

    /**
     * Save a new resource or update an existing resource.
     *
     * @param  App\Labour $labour
     * @param  \Illuminate\Http\Request  $request
     * @param  string $fileNameToStore
     * @return Boolean
     */
    private function setChamber(Chamber $chamber,Request $request){
        $chamber->chambers_name   = $request->input('chambers_name');
        $chamber->dimension    = $request->input('dimension');
        $chamber->created_by      = $request->input('created_by');
        $chamber->updated_by        = $request->input('updated_by');
        $chamber->unit_id      = $request->input('unit');
        
        
        $chamber->save();
    }


}
