<?php

namespace App\Http\Controllers;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use App\Models\Contractor;

class ContractorsController extends Controller
{
    
    public function __construct(){
        $this->middleware('auth');
    }

    public function index()
    {
        $contractors = Contractor::Paginate(20);
        return view('contractors.index')->with('contractors',$contractors);
    }

  
    public function create()
    {
        return view('contractors.create');
    }

    public function store(Request $request)
    {   
        
        $this->validate($request,[
            'first_name'     =>  'required|min:3|max:50|',
            'last_name'      =>  'required|min:3|max:50|',
            'address'        => 'required|min:4|max:500',
            'created_by'     => '',
            'phone_no'       =>  'required|min:10|max:10|unique:contractors',
            'updated_by'     => ''
        ]);
        
      
        $contractor = new Contractor();
        
       
        $this->setContractor($contractor,$request);
        
        return redirect('/contractors')->with('info','Contractor has been Created!');
    }

    public function show($id)
    {
        $contractor = Contractor::find($id);
        return view('contractors.show')->with('contractor',$contractor);
    }

    public function edit($id)
    {
        /**
         *  this is same as create but with an existing
         *  employee
         */
        $contractor = Contractor::find($id);
        return view('contractors.edit')->with('contractor',$contractor);
    }

   
    public function update(Request $request, $id)
    {

        $this->validate($request,[
            'first_name'     =>  'required|min:3|max:50|',
            'last_name'      =>  'required|min:3|max:50|',
            'address'        => 'required|min:4|max:500',
            'created_by'     => '',
            'phone_no'       =>  'required|max:10|min:10',
            'updated_by'     => ''
        ]);
        $contractor = Contractor::find($id);
    
        $this->setContractor($contractor,$request);
        return redirect('/contractors')->with('info','Selected Contractor has been updated!');
    }

    public function destroy($id)
    {
        $contractor = contractor::find($id);
        $contractor->delete();
        return redirect('/contractors')->with('info','Selected Contractor has been deleted!');
    }


    public function search(Request $request){
        $this->validate($request,[
            'search' => 'required'
        ]);
        $str = $request->input('search');
        $contractors = Contractor::where( 'first_name' , 'LIKE' , '%'.$str.'%' )
            ->orderBy('first_name','asc')
            ->paginate(4);
        return view('contractors.index')->with([ 'contractors' => $contractors ,'search' => true ]);
    }

    
    // private function validateRequest($request,$id){
      
    //     return $this->validate($request,[
    //         'first_name'     =>  'required|min:3|max:50|',
    //         'last_name'      =>  'required|min:3|max:50|',
    //         'address'        => 'required|min:4|max:500',
    //         'created_by'     => '',
    //         // 'phone_no'       =>  'required|max:10|unique:contractors',
    //         'updated_by'     => ''
    //     ]);
    // }

 
    private function setContractor(Contractor $contractor,Request $request){
       
        $contractor->first_name   = $request->input('first_name');
        $contractor->last_name    = $request->input('last_name');
        $contractor->address      = $request->input('address');
        $contractor->phone_no     = $request->input('phone_no');
        $contractor->created_by   = Auth::user()->username;
        $contractor->updated_by   = Auth::user()->username;
        $contractor->save();
        
    }

}
