<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Customer;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;

class CustomersController extends Controller
{
    /**
     *  Only authenticated users can access this controller
     */
    public function __construct(){
        $this->middleware('auth');
    }

   
    public function index()
    {
         
        $customers = Customer::Paginate(20);
        return view('customers.index')->with('customers',$customers);
    }

    public function create()
    {
        return view('customers.create');
    }

    public function store(Request $request)
    {
        $customer = new Customer();
        $this->validate($request,[
            'first_name'     =>  'required|min:3|max:50|',
            'last_name'      =>  'required|min:3|max:50|',
            'address'        => 'required|min:4|max:500',
           
            'phone_no'       =>  'required|max:10|min:10|unique:customers',
            
        ]);
        $this->setCustomer($request ,$customer);
        return redirect('/customers/create')->with('info','New Customer has been created!');
    }

    public function edit($id)
    {
        $customer = Customer::find($id);
        return view('customers.edit')->with('customer',$customer);
    }

    public function update(Request $request, $id)
    {
        $this->validate($request,[
            'first_name'     =>  'required|min:3|max:50|',
            'last_name'      =>  'required|min:3|max:50|',
            'address'        => 'required|min:4|max:500',
           
            'phone_no'       =>  'required|min:10|max:10',
            
        ]);
        
        $customer = Customer::find($id);
        
        $this->setCustomer($request, $customer);
        return redirect('/customers')->with('info','selected Customer has been updated');
    }

    public function destroy($id)
    {
      
        if($id == Auth::customer()->id){
           
            return redirect('/customers')->with('info','Authenticated Customer cannot be deleted!');
        }
        
        $customer = Customer::find($id);
        $customer->delete();
        return redirect('/customers')->with('info','selected Customer has been deleted!');
    }

    public function search(Request $request){
        $this->validate($request,[
            'search' => 'required',
            'options' => 'required',
        ]);
        $str = $request->input('search');
        $option = $request->input('options');
        $customers = Customer::where( $option , 'LIKE' , '%'.$str.'%' )
            ->orderBy($option,'asc')
            ->paginate(4);
        return view('customers.index')->with([ 'customers' => $customers ,'search' => true ]);
    }

    /**
     *  Validate all the inputs
     */
    // private function validateRequest(Request $request, $id)
    // {
    //     $this->validate($request,[
    //         'first_name'   =>  'required|min:3',
    //         'last_name'    =>  'required|min:3',
    //         'address'        =>  'required|min:10|max:500',
          
         
    //     ]);
    // }

    /**
     * Add or update an admin
     */
    private function setCustomer(Request $request , Customer $customer){
        $customer->first_name = $request->input('first_name');
        $customer->last_name = $request->input('last_name');
        $customer->phone_no     = $request->input('phone_no');
        $customer->address      = $request->input('address');
        $customer->save();
    }

    public function backToPreviousURL(){
        return Redirect::to(url()->previous());
    }

}
