<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Labour;
use App\Models\Bricksclass;
use App\Models\Unit;
use App\Models\Customer;
use App\Models\Chamber;
use App\Models\Sale;
use App\Models\Inventory;
use App\Salary;
use App\Models\User;
use Carbon\Carbon;
use DB;

class DashboardController extends Controller
{
    /**
     *  Only authenticated users can access this controller
     */
    public function __construct(){
        $this->middleware('auth');
    }
    
    /**
     * Show Dashboard View
     *
     * @return View
     */
    public function index(){
        //get Current date and time
        $date_current = Carbon::now()->toDateTimeString();
        //get date and time of previous month
        /**
         *  subMonths() means it will subtract the month with
         *  the given argument.
         */
        $prev_date1 = $this->getPrevDate(1);
        $prev_date2 = $this->getPrevDate(2);
        $prev_date3 = $this->getPrevDate(3);
        $prev_date4 = $this->getPrevDate(4);

        /**
         *  get count of employee between two given dates.
         */
        $emp_count_1 = Sale::whereBetween('sale_at',[$prev_date1,$date_current])->count();
        $emp_count_2 = Sale::whereBetween('sale_at',[$prev_date2,$prev_date1])->count();
        $emp_count_3 = Sale::whereBetween('sale_at',[$prev_date3,$prev_date2])->count();
        $emp_count_4 = Sale::whereBetween('sale_at',[$prev_date4,$prev_date3])->count();

        $t_users = User::all()->count();
        $t_labours = Labour::all()->count();
        $t_chambers = Chamber::all()->count();
        $t_inventories = Inventory::all()->count();
         $t_bricksclasses = Bricksclass::all()->count();
        $t_units = Unit::all()->count();
        $t_customers = Customer::all()->count();
        $t_sales = Sale::all()->count();


        return view('dashboard.index')
            ->with([
                'emp_count_1'     =>  $emp_count_1,
                'emp_count_2'     =>  $emp_count_2,
                'emp_count_3'     =>  $emp_count_3,
                'emp_count_4'     =>  $emp_count_4,
                't_labours'     =>  $t_labours,
                't_chambers'     =>  $t_chambers,
                 't_bricksclasses'        =>  $t_bricksclasses,
                't_inventories'        =>  $t_inventories,
                't_sales'      =>  $t_sales,
                't_customers'     =>  $t_customers,
                't_units'   =>  $t_units,
                't_users'        =>  $t_users
            ]);
    }

    /**
     *  get the sub month of the given integer
     */
    private function getPrevDate($num){
        return Carbon::now()->subMonths($num)->toDateTimeString();
    }
}
