<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Models\Inventory;
use App\Models\Unit;
use App\Models\Bricksclass;
use DB;

class InventoryController extends Controller
{
   /**
     *  Only authenticated users can access this controller
     */
    public function __construct(){
        $this->middleware('auth');
    }

    
    public function index()
    {
        $inventories = Inventory::Paginate(20);
        return view('inventories.index')->with('inventories',$inventories);
    }

    
    public function create()
    {
        
        $units = Unit::orderBy('unit_name','asc')->get();
        $bricksclasses = Bricksclass::orderBy('bricksclass_name','asc')->get();

     
        return view('inventories.create')->with([
            'units'  => $units,
            'bricksclasses' => $bricksclasses,
        ]);
    }

   
    public function store(Request $request)
    {   
        
        $this->validateRequest($request,null);
        
        
        $inventory = new Inventory();
        
       
        $this->setInventory($inventory,$request);
        
        return redirect('/inventories')->with('info','New Inventory has been created!');
    }

    public function show($id)
    {
        $inventory = Inventory::find($id);
        return view('inventories.show')->with('inventory',$inventory);
    }

    public function edit($id)
    {
        
        $units = Unit::orderBy('unit_name','asc')->get();
        $bricksclasses = Bricksclass::orderBy('bricksclass_name','asc')->get();

        $inventory = Inventory::find($id);
     
        return view('inventories.edit')->with([
            'units'  => $units,
            'inventory' => $inventory,
            'bricksclasses' => $bricksclasses,
          
        ]);
    }

   
    public function update(Request $request, $id)
    {

        $this->validateRequest($request,$id);
        $inventory = Inventory::find($id);
    
        $this->setInventory($inventory,$request);
        return redirect('/inventories')->with('info','Selected Inventory has been updated!');
    }

    public function destroy($id)
    {
        $inventory = Inventory::find($id);
        $inventory->delete();
        return redirect('/inventories')->with('info','Selected Inventory has been deleted!');
    }

    public function search(Request $request){
        $this->validate($request,[
            'search'   => 'required|min:1',
            'options'  => 'required'
        ]);
        $str = $request->input('search');
        $option = $request->input('options');

        $inventories = new Inventory();
        if($option == 'unit_name'){
            $units = Unit::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($units)){
        
                foreach($units as $unit) {
                    $u_id[] = $unit->id;
                   } 
                $units_ids = implode(',',$u_id);
                // print_r($unit_ids);
                $inventories = Inventory::whereIn('units_id' , [$units_ids])
                ->paginate(20);
                // print_r($sales);
            }
        }elseif($option == 'bricksclass_name'){
            $bricks = Bricksclass::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($bricks)){
        
                foreach($bricks as $brick) {
                    $b_id[] = $brick->id;
                   } 
                $bricksclass_ids = implode(',',$b_id);
                // print_r($unit_ids);
                $inventories = Inventory::whereIn('bricksclass_id' , [$bricksclass_ids])
                ->paginate(20);
                // print_r($sales);
            }

        }elseif($option == 'created_at'){

        $inventories = Inventory::where('created_at', 'LIKE' , '%'.$str.'%')
        ->orderBy('created_at','asc')
        ->Paginate(4);
        }
        else{
        $inventories = Inventory::where($option, 'LIKE' , '%'.$str.'%')->Paginate(4);
        }
        return view('inventories.index')->with(['inventories' => $inventories , 'search' => true ]);
    }

    private function validateRequest($request,$id){
     
        return $this->validate($request,[
            'unit'     =>  'required',
            'bricksclass' => 'required',
            'no_of_bricks' => 'required',
          
         
            
        ]);
    }

    private function setInventory(Inventory $inventory,Request $request){
       
        $inventory->units_id      = $request->input('unit');
        $inventory->bricksclass_id      = $request->input('bricksclass');
        $inventory->no_of_bricks      = $request->input('no_of_bricks');
        
        $inventory->save();
    }


}
