<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Models\Labour;
use App\Models\Unit;
use App\Models\Contractor;
use DB;

class LaboursController extends Controller
{
   /**
     *  Only authenticated users can access this controller
     */
    public function __construct(){
        $this->middleware('auth');
    }

    
    public function index()
    {
        $labours = Labour::Paginate(20);
        return view('labours.index')->with('labours',$labours);
    }

    
    public function create()
    {
        
        $units = Unit::orderBy('unit_name','asc')->get();
        $contractors = Contractor::orderBy('first_name','asc')->get();

     
        return view('labours.create')->with([
            'units'  => $units,
            'contractors' => $contractors,
        ]);
    }

   
    public function store(Request $request)
    {   
        
        $this->validate($request,[
            'first_name'     =>  'required|min:3|max:50',
            'last_name'      =>  'required|min:3|max:50',
            'address'        =>  'required|min:10|max:500',
            'phone_no'          =>  'required|max:10|min:10|unique:labours',
            'unit'     =>  'required',
            'join_date'      =>  'required',
            'birth_date'     =>  'required',
            'contractor' => '',
          
         
            
        ]);
        
        
        $labour = new Labour();
        
       
        $this->setLabour($labour,$request);
        
        return redirect('/labours')->with('info','New Labour has been created!');
    }

    public function show($id)
    {
        $labour = Labour::find($id);
        return view('labours.show')->with('labour',$labour);
    }

    public function edit($id)
    {
        
        $units = Unit::orderBy('unit_name','asc')->get();
        $contractors = Contractor::orderBy('first_name','asc')->get();

        $labour = Labour::find($id);
     
        return view('labours.edit')->with([
            'units'  => $units,
            'labour' => $labour,
            'contractors' => $contractors,
          
        ]);
    }

   
    public function update(Request $request, $id)
    {

        $this->validate($request,[
            'first_name'     =>  'required|min:3|max:50',
            'last_name'      =>  'required|min:3|max:50',
            'address'        =>  'required|min:10|max:500',
            'phone_no'          =>  'required|max:10|min:10|',
            'unit'     =>  'required',
            'join_date'      =>  'required',
            'birth_date'     =>  'required',
            'contractor' => '',
          
         
            
        ]);
        $labour = Labour::find($id);
    
        $this->setLabour($labour,$request);
        return redirect('/labours')->with('info','Selected Labour has been updated!');
    }

    public function destroy($id)
    {
        $labour = Labour::find($id);
        $labour->delete();
        return redirect('/labours')->with('info','Selected Labour has been deleted!');
    }

    public function search(Request $request){
        $this->validate($request,[
            'search'   => 'required|min:1',
            'options'  => 'required'
        ]);
        $str = $request->input('search');
        $option = $request->input('options');
        $labours = new Labour();
        if($option == 'unit_name'){
            $units = Unit::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($units)){
        
                foreach($units as $unit) {
                    $u_id[] = $unit->id;
                   } 
                $unit_ids = implode(',',$u_id);
                // print_r($unit_ids);
                $labours = Labour::whereIn('unit_id' , [$unit_ids])
                ->paginate(20);
                // print_r($sales);
            }
        }
        else{
        $labours = Labour::where($option, 'LIKE' , '%'.$str.'%')->Paginate(4);
        }
        return view('labours.index')->with(['labours' => $labours , 'search' => true ]);
    }

    // private function validateRequest($request,$id){
     
    //     return $this->validate($request,[
    //         'first_name'     =>  'required|min:3|max:50',
    //         'last_name'      =>  'required|min:3|max:50',
    //         'address'        =>  'required|min:10|max:500',
    //         'phone_no'          =>  'required|max:13',
    //         'unit'     =>  'required',
    //         'join_date'      =>  'required',
    //         'birth_date'     =>  'required',
    //         'contractor' => '',
          
         
            
    //     ]);
    // }

    private function setLabour(Labour $labour,Request $request){
        $labour->first_name   = $request->input('first_name');
        $labour->last_name    = $request->input('last_name');
        $labour->address      = $request->input('address');
        $labour->phone_no        = $request->input('phone_no');
        //Format Date then insert it to the database
        $labour->join_date    = date('Y-m-d', strtotime(str_replace('-', '/', $request->input('join_date'))));
        //Format Date then insert it to the database
        $labour->birth_date   = date('Y-m-d', strtotime(str_replace('-', '/', $request->input('birth_date'))));
      
        $labour->unit_id      = $request->input('unit');
        $labour->contractor_id      = $request->input('unit');
        
        $labour->save();
    }


}
