<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Models\Loading;
use App\Models\Labour;
use App\Models\Tika;
use App\Models\Chamber;
use DB;

class LoadingsController extends Controller
{
  
    public function __construct(){
        $this->middleware('auth');
    }

   
    public function index()
    {
        $loadings = Loading::Paginate(20);
        return view('loadings.index')->with('loadings',$loadings);
    }

    public function create()
    {
        $tikas = Tika::orderBy('tika_name','asc')->get();
        $chambers = Chamber::orderBy('chambers_name','asc')->get();
        $labours = Labour::orderBy('first_name','asc')->get();

     
        return view('loadings.create')->with([
            'tikas'  => $tikas,
            'chambers' => $chambers,
            'labours' => $labours,
        ]);
    }

    
    public function store(Request $request)
    {   
        
        $this->validateRequest($request,null);
        $loading = new Loading();
        $this->setLoading($loading,$request);

        switch ($request->input('sbbtn')) {
            case '1':
                return redirect('/loadings/create')->with('info','New Loading has been created!');
                break;
    
            case '2':
                return redirect('/loadings')->with('info','New Loading has been created!');
                break;
    
           
        }
        
        
    }

   
    public function show($id)
    {
        $loading = Loading::find($id);
        return view('loadings.show')->with('loading',$loading);
    }

    
    public function edit($id)
    {
        
        $tikas = Tika::orderBy('tika_name','asc')->get();
        $chambers = Chamber::orderBy('chambers_name','asc')->get();
        $labours = Labour::orderBy('first_name','asc')->get();

        $loading = Loading::find($id);
     
        return view('loadings.edit')->with([
            'tikas'  => $tikas,
            'chambers' => $chambers,
            'labours' => $labours,
            'loading' => $loading,
            
          
        ]);
    }

  
    public function update(Request $request, $id)
    {

        $this->validateRequest($request,$id);
        $loading = Loading::find($id);
    
        $this->setLoading($loading,$request);
        return redirect('/loadings')->with('info','Selected Loading has been updated!');
    }

    
    public function destroy($id)
    {
        $loading = Loading::find($id);
        $loading->delete();
        return redirect('/loadings')->with('info','Selected Loading has been deleted!');
    }

    
    public function search(Request $request){
        $this->validate($request,[
            'search'   => 'required|min:1',
            'options'  => 'required'
           
        ]);
        $str = $request->input('search');
        $option = $request->input('options');
        $loadings = new Loading();
        if($option == 'tika_name'){
            $tikas = Tika::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($tikas)){
        
                foreach($tikas as $tika) {
                    $t_id[] = $tika->id;
                   } 
                $tika_ids = implode(',',$t_id);
                // print_r($unit_ids);
                $loadings = Loading::whereIn('tika_id' , [$tika_ids])
                ->paginate(20);
                // print_r($sales);
            }
        }elseif($option == 'chambers_name'){
            $chambers = Chamber::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($chambers)){
        
                foreach($chambers as $chamber) {
                    $c_id[] = $chamber->id;
                   } 
                $chambers_ids = implode(',',$c_id);
                // print_r($unit_ids);
                $loadings = Loading::whereIn('chambers_id' , [$chambers_ids])
                ->paginate(20);
                // print_r($sales);
            }

        }
        elseif($option == 'first_name'){

            $labours = Labour::where('first_name', 'LIKE' , '%'.$str.'%')
                               ->orWhere('last_name', 'LIKE' , '%'.$str.'%')
                               ->orWhereRaw('CONCAT_WS(" ", trim(first_name), trim(last_name)) like "%' . $str . '%"')
                               ->get(['id']);
            // print_r($labours);
            
            if(isset($labours)){
                $l_id = [];
                foreach($labours as $labour) {
                    $l_id[] = $labour->id;
                   } 
                $labours_ids = implode(',',$l_id);
                print_r($labours_ids);
                $loadings = Loading::whereIn('labours_id' , [$labours_ids])
                ->paginate(20);
                // print_r($sales);
            }
            }
        elseif($option == 'loading_at'){

        $loadings = Loading::where('loading_at', 'LIKE' , '%'.$str.'%')
        ->orderBy('loading_at','asc')
        ->Paginate(4);
        }
        else{
        $loadings = Loading::where($option, 'LIKE' , '%'.$str.'%')->Paginate(20);
        
        }
        return view('loadings.index')->with(['loadings' => $loadings , 'search' => true ]);
    }

    
    private function validateRequest($request,$id){
       
        return $this->validate($request,[
            'loading_at' => 'required',
            'tika'     =>  'required',
            'no_of_tika'=>'',
            'chamber' => '',
            'labour' => '',
            'created_by' =>'',
            'updated_by' => '',
          
         
            
        ]);
    }

    
    private function setLoading(Loading $loading,Request $request){
     
        $loading->loading_at    = date('Y-m-d', strtotime(str_replace('-', '/', $request->input('loading_at'))));
       
        $loading->tika_id      = $request->input('tika');
        $loading->no_of_tika      = $request->input('no_of_tika');
        $loading->chambers_id      = $request->input('chamber');
        $loading->labours_id      = $request->input('labour');
        $loading->save();
    }


}
