<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Models\Moulding;
use App\Models\Labour;
use App\Models\Unit;
use DB;

class MouldingsController extends Controller
{
   
    public function __construct(){
        $this->middleware('auth');
    }

    
    public function index()
    {
        $mouldings = Moulding::Paginate(20);
        return view('mouldings.index')->with('mouldings',$mouldings);
    }

  
    public function create()
    {
        $units = Unit::orderBy('unit_name','asc')->get();
        $labours = Labour::orderBy('first_name','asc')->get();

     
        return view('mouldings.create')->with([
            'units'  => $units,
            'labours' => $labours,
        ]);
    }

    public function store(Request $request)
    {   
        
        $this->validateRequest($request,null);
        
        
        $moulding = new Moulding();
        
        
        $this->setMoulding($moulding,$request);

        switch ($request->input('sbbtn')) {
            case '1':
                return redirect('/mouldings/create')->with('info','New Moulding has been created!');
                break;
    
            case '2':
                return redirect('/mouldings')->with('info','New Moulding has been created!');
                break;
    
           
        }
        
       
    }

    public function show($id)
    {
        $moulding = Moulding::find($id);
        return view('mouldings.show')->with('moulding',$moulding);
    }

    
    public function edit($id)
    {
        
        $units = Unit::orderBy('unit_name','asc')->get();
        $labours = Labour::orderBy('first_name','asc')->get();

        $moulding = Moulding::find($id);
     
        return view('mouldings.edit')->with([
            'units'  => $units,
            'labours' => $labours,
            'moulding' => $moulding,
            
          
        ]);
    }

   
    public function update(Request $request, $id)
    {

        $this->validateRequest($request,$id);
        $moulding = Moulding::find($id);
    
        $this->setMoulding($moulding,$request);
        return redirect('/mouldings')->with('info','Selected Moulding has been updated!');
    }

    
    public function destroy($id)
    {
        $moulding = Moulding::find($id);
        $moulding->delete();
        return redirect('/mouldings')->with('info','Selected Moulding has been deleted!');
    }

    public function search(Request $request){
        $this->validate($request,[
            'search'   => 'required|min:1',
            'options'  => 'required'
           
        ]);
        $str = $request->input('search');
        $option = $request->input('options');
        $mouldings = new Moulding();
        if($option == 'unit_name'){
            $tikas = Tika::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($units)){
        
                foreach($units as $unit) {
                    $u_id[] = $unit->id;
                   } 
                $unit_ids = implode(',',$u_id);
                // print_r($unit_ids);
                $mouldings = Moulding::whereIn('unit_id' , [$unit_ids])
                ->paginate(20);
                // print_r($sales);
            }
        }
        elseif($option == 'first_name'){

            $labours = Labour::where('first_name', 'LIKE' , '%'.$str.'%')
                               ->orWhere('last_name', 'LIKE' , '%'.$str.'%')
                               ->orWhereRaw('CONCAT_WS(" ", trim(first_name), trim(last_name)) like "%' . $str . '%"')
                               ->get(['id']);
            // print_r($labours);
            
            if(isset($labours)){
                $l_id = [];
                foreach($labours as $labour) {
                    $l_id[] = $labour->id;
                   } 
                $labours_ids = implode(',',$l_id);
                print_r($labours_ids);
                $mouldings = Moulding::whereIn('labours_id' , [$labours_ids])
                ->paginate(20);
                // print_r($sales);
            }
            }
        elseif($option == 'moulding_at'){

        $mouldings = Moulding::where('moulding_at', 'LIKE' , '%'.$str.'%')
        ->orderBy('moulding_at','asc')
        ->Paginate(4);
        }
        else{
        $mouldings = Moulding::where($option, 'LIKE' , '%'.$str.'%')->Paginate(20);
        
        }
        return view('mouldings.index')->with(['mouldings' => $mouldings , 'search' => true ]);
    }

    
    private function validateRequest($request,$id){
      
        return $this->validate($request,[
            'moulding_at' => 'required',
            'unit'     =>  'required',
            'no_of_bricks'=>'',
            'chamber' => '',
            'labour' => '',
            'created_by' =>'',
            'updated_by' => '',
          
         
            
        ]);
    }

    private function setMoulding(moulding $moulding,Request $request){
     
        $moulding->moulding_at    = date('Y-m-d', strtotime(str_replace('-', '/', $request->input('moulding_at'))));
       
        $moulding->unit_id      = $request->input('unit');
        $moulding->no_of_bricks      = $request->input('no_of_bricks');
        $moulding->labours_id      = $request->input('labour');
        $moulding->save();
    }


}
