<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\Unit;

class UnitsController extends Controller
{
    
    public function __construct(){
        $this->middleware('auth');
    }

    public function index()
    {
        $units = Unit::orderBy('unit_name','asc')->Paginate(20);
        return view('sys_mg.units.index')->with('units',$units);
    }

  
    public function create()
    {
        return view('sys_mg.units.create');
    }

    public function store(Request $request)
    {   
        
        $this->validate($request,[
            'unit_name' => 'required|unique:units|min:4',
            'address'=> 'required|min:4',
            'no_of_chamber'=> 'required',
            'created_by'=> '',
            'updated_by'=> '' 
        ]);
        
      
        $unit = new Unit();
        $unit->unit_name = $request->input('unit_name');
        $unit->address = $request->input('address');
        $unit->no_of_chamber = $request->input('no_of_chamber');
        $unit->created_by = Auth::user()->username;
        $unit->updated_by =Auth::user()->username;
        $unit->save();
        
        return redirect('/units')->with('info','Unit has been Created!');
    }

    public function show($id)
    {
        // $unit = Unit::find($id);
        // return view('sys_mg.units.show')->with('unit',$unit);
    }

    public function edit($id)
    {
        /**
         *  this is same as create but with an existing
         *  employee
         */
        $unit = Unit::find($id);
        return view('sys_mg.units.edit')->with('unit',$unit);
    }

   
    public function update(Request $request, $id)
    {

        $this->validate($request,[
            'unit_name' => 'required|min:4',
            'address'=> 'required|min:4',
            'no_of_chamber'=> 'required',
            'updated_by'=> '' 
        ]);
        $unit = Unit::find($id);
        $unit->unit_name = $request->input('unit_name');
        $unit->address = $request->input('address');
        $unit->no_of_chamber = $request->input('no_of_chamber');
        $unit->updated_by = Auth::user()->username;
        $unit->save();
        
        return redirect('/units')->with('info','Selected Unit has been updated!');
    }

    public function destroy($id)
    {
        $unit = Unit::find($id);
        $unit->delete();
        return redirect('/units')->with('info','Selected Unit has been deleted!');
    }


    public function search(Request $request){
        $this->validate($request,[
            'search' => 'required'
        ]);
        $str = $request->input('search');
        $units = Unit::where( 'unit_name' , 'LIKE' , '%'.$str.'%' )
            ->orderBy('unit_name','asc')
            ->paginate(4);
        return view('sys_mg.units.index')->with([ 'units' => $units ,'search' => true ]);
    }

    
    // private function validateRequest($request,$id){
      
    //     return $this->validate($request,[
    //         'unit_name' => 'required|unique:units|min:4',
    //         'address'=> 'required|min:4',
    //         'created_by'=> '',
    //         'updated_by'=> '' 
    //     ]);
    // }

 
    // private function setUnit(Unit $unit,Request $request){
       
    //     $unit->unit_name = $request->input('unit_name');
    //     $unit->address = $request->input('address');
    //     $unit->created_by = $request->input('created_by');
    //     $unit->updated_by = $request->input('updated_by');
    //     $unit->save();
    // }

}
