<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Models\Unloading;
use App\Models\Labour;
use App\Models\Tika;
use App\Models\Chamber;
use DB;

class UnloadingsController extends Controller
{
   /**
     *  Only authenticated users can access this controller
     */
    public function __construct(){
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $unloadings = Unloading::Paginate(20);
        return view('unloadings.index')->with('unloadings',$unloadings);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $tikas = Tika::orderBy('tika_name','asc')->get();
        $chambers = Chamber::orderBy('chambers_name','asc')->get();
        $labours = Labour::orderBy('first_name','asc')->get();

     
        return view('unloadings.create')->with([
            'tikas'  => $tikas,
            'chambers' => $chambers,
            'labours' => $labours,
        ]);
    }

    public function store(Request $request)
    {   
        
        $this->validateRequest($request,null);
        
       
        $unloading = new Unloading();
        
        
        $this->setUnloading($unloading,$request);

        switch ($request->input('sbbtn')) {
            case '1':
                return redirect('/unloadings/create')->with('info','New Unloading has been created!');
                break;
    
            case '2':
                return redirect('/unloadings')->with('info','New Unloading has been created!');
                break;
    
           
        }
        
        
    }

    public function show($id)
    {
        $unloading = Unloading::find($id);
        return view('unloadings.show')->with('unloading',$unloading);
    }

    public function edit($id)
    {
       
        $tikas = Tika::orderBy('tika_name','asc')->get();
        $chambers = Chamber::orderBy('chambers_name','asc')->get();
        $labours = Labour::orderBy('first_name','asc')->get();

        $unloading = Unloading::find($id);
     
        return view('unloadings.edit')->with([
            'tikas'  => $tikas,
            'chambers' => $chambers,
            'labours' => $labours,
            'unloading' => $unloading,
            
          
        ]);
    }

    public function update(Request $request, $id)
    {

        $this->validateRequest($request,$id);
        $unloading = Unloading::find($id);
    
        $this->setUnloading($unloading,$request);
        return redirect('/unloadings')->with('info','Selected Unloading has been updated!');
    }

    public function destroy($id)
    {
        $unloading = Unloading::find($id);
        $unloading->delete();
        return redirect('/unloadings')->with('info','Selected Unloading has been deleted!');
    }

    public function search(Request $request){
        $this->validate($request,[
            'search'   => 'required|min:1',
            'options'  => 'required'
        ]);
        $str = $request->input('search');
        $option = $request->input('options');
        $unloadings = new Unloading();
        if($option == 'tika_name'){
            $tikas = Tika::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($tikas)){
        
                foreach($tikas as $tika) {
                    $t_id[] = $tika->id;
                   } 
                $tika_ids = implode(',',$t_id);
                // print_r($unit_ids);
                $unloadings = Unloading::whereIn('tika_id' , [$tika_ids])
                ->paginate(20);
                // print_r($sales);
            }
        }elseif($option == 'chambers_name'){
            $chambers = Chamber::where($option, 'LIKE' , '%'.$str.'%')->get(['id']);
            
            if(isset($chambers)){
        
                foreach($chambers as $chamber) {
                    $c_id[] = $chamber->id;
                   } 
                $chambers_ids = implode(',',$c_id);
                // print_r($unit_ids);
                $unloadings = Unloading::whereIn('chambers_id' , [$chambers_ids])
                ->paginate(20);
                // print_r($sales);
            }

        }elseif($option == 'unloading_at'){

        $unloadings = Unloading::where('unloading_at', 'LIKE' , '%'.$str.'%')
        ->orderBy('unloading_at','asc')
        ->Paginate(4);
        }
        elseif($option == 'first_name'){

            $labours = Labour::where('first_name', 'LIKE' , '%'.$str.'%')
                               ->orWhere('last_name', 'LIKE' , '%'.$str.'%')
                               ->orWhereRaw('CONCAT_WS(" ", trim(first_name), trim(last_name)) like "%' . $str . '%"')
                               ->get(['id']);
            // print_r($labours);
            
            if(isset($labours)){
                $l_id = [];
                foreach($labours as $labour) {
                    $l_id[] = $labour->id;
                   } 
                $labours_ids = implode(',',$l_id);
                // print_r($unit_ids);
                $unloadings = Unloading::whereIn('labours_id' , [$labours_ids])
                ->paginate(20);
                // print_r($sales);
            }
            }
        else{
        $unloadings = Unloading::where($option, 'LIKE' , '%'.$str.'%')->Paginate(20);
        
        }
        return view('unloadings.index')->with(['unloadings' => $unloadings , 'search' => true ]);
    }

    
    private function validateRequest($request,$id){
       
        return $this->validate($request,[
            'unloading_at' => 'required',
            'tika'     =>  'required',
            'no_of_tika'=>'',
            'chamber' => '',
            'labour' => '',
            'created_by' =>'',
            'updated_by' => '',
          
         
            
        ]);
    }

    private function setUnloading(Unloading $unloading,Request $request){
     
        $unloading->unloading_at    = date('Y-m-d', strtotime(str_replace('-', '/', $request->input('unloading_at'))));
       
        $unloading->tika_id      = $request->input('tika');
        $unloading->no_of_tika      = $request->input('no_of_tika');
        $unloading->chambers_id      = $request->input('chamber');
        $unloading->labours_id      = $request->input('labour');
        $unloading->save();
    }


}
