<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Role;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;

class UsersController extends Controller
{
    /**
     *  Only authenticated users can access this controller
     */
    public function __construct(){
        $this->middleware('auth');
    }

   
    public function index()
    {
         
        $users = User::Paginate(20);
        return view('users.index')->with('users',$users);
    }

    public function create(Request $request)
    {
        if($request->ajax()){
            $roles = Role::where('id', $request->role_id)->first();
            $permissions = $roles->permissions;

            return $permissions;
        }

        $roles = Role::all();
        return view('users.create', ['roles' => $roles]);
    }

    public function store(Request $request)
    {
        $user = new User();
        $this->validateRequest($request,NULl,['phone_no'       =>  'required|max:13|unique:users',]);
        $this->setUser($request ,$user);
        if($request->role != null){
            $user->roles()->attach($request->role);
            $user->save();
        }

        if($request->permissions != null){            
            foreach ($request->permissions as $permission) {
                $user->permissions()->attach($permission);
                $user->save();
            }
        }
        return redirect('/users')->with('info','New User has been created!');
    }

    public function edit($id)
    {
        $user = User::find($id);
        $roles = Role::get();
        $userRole = $user->roles->first();
        if($userRole != null){
            $rolePermissions = $userRole->allRolePermissions;
        }else{
            $rolePermissions = null;
        }
        $userPermissions = $user->permissions;

        // dd($rolePermission);

        return view('users.edit', [
            'user'=>$user,
            'roles'=>$roles,
            'userRole'=>$userRole,
            'rolePermissions'=>$rolePermissions,
            'userPermissions'=>$userPermissions
            ]);
    }

    public function update(Request $request, $id)
    {
        $this->validateRequest($request,$id,['phone_no'       =>  '']);
        
        $user = User::find($id);
        
        $this->setUser($request, $user);
        $user->roles()->detach();
        $user->permissions()->detach();

        if($request->role != null){
            $user->roles()->attach($request->role);
            $user->save();
        }

        if($request->permissions != null){            
            foreach ($request->permissions as $permission) {
                $user->permissions()->attach($permission);
                $user->save();
            }
        }
        return redirect('/users')->with('info','selected user has been updated');
    }

    public function destroy($id)
    {
      
        if($id == Auth::user()->id){
           
            return redirect('/users')->with('info','Authenticated User cannot be deleted!');
        }
        
        $user = User::find($id);
        $user->delete();
        $user->roles()->detach();
        $user->permissions()->detach();
        return redirect('/users')->with('info','selected user has been deleted!');
    }

    public function search(Request $request){
        $this->validate($request,[
            'search' => 'required',
            'options' => 'required',
        ]);
        $str = $request->input('search');
        $option = $request->input('options');
        $users = User::where( $option , 'LIKE' , '%'.$str.'%' )
            ->orderBy($option,'asc')
            ->paginate(4);
        return view('users.index')->with([ 'users' => $users ,'search' => true ]);
    }

    /**
     *  Validate all the inputs
     */
    private function validateRequest(Request $request, $id)
    {
        $this->validate($request,[
            'first_name'   =>  'required|min:3',
            'last_name'    =>  'required|min:3',
            'password'     =>  ''.( $id ? 'nullable|min:7' : 'required|min:7' ),
            'username'     =>  'required|unique:users,username,'.($id ? : '' ).'|min:3',
            'email'        =>  '',
            'phone_no'       =>  'required|max:10|unique:users',
            'role'=> '',
         
        ]);
    }

    /**
     * Add or update an admin
     */
    private function setUser(Request $request , User $user){
        $user->first_name = $request->input('first_name');
        $user->last_name = $request->input('last_name');
        $user->username = $request->input('username');
        $user->email = $request->input('email');
        if($request->input('password') != NULL){
            $user->password = bcrypt($request->input('password'));
        }
        $user->phone_no     = $request->input('phone_no');
        $user->role     = $request->input('role');
        $user->save();
    }

}
