@extends('layouts.app')
@section('content')
<div class="container">
    <h4 class="grey-text text-darken-2 center">Contractor List</h4>
    
    {{-- Include the searh component with with title and route --}}
    @component('sys_mg.inc.search',['title' => 'Contractor' , 'route' => 'contractors.search'])
    @endcomponent
    
    <div class="row">
        {{-- Show All Contractors List as a Card --}}
        <div class="card col s12 m12 l12 xl12">
            <div class="card-content">
                <div class="row">
                    <h5 class="pl-15 grey-text text-darken-2">Contractor List</h5>
                    {{-- Table that shows Contractors List --}}
                    <table class="responsive-table col s12 m12 l12 xl12">
                        <thead class="grey-text text-darken-2">
                            <tr>
                                <th>ID</th>
                                <th>Contractor Name</th>
                                <th>Created at</th>
                                <th>Created by</th>
                                <th>Phone No</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody id="contractor-table">
                            {{-- Check if there are any contractors to render in view --}}
                            @if($contractors->count())
                                @foreach($contractors as $contractor)
                                    <tr>
                                        <td>{{$contractor->id}}</td>
                                        <td>{{$contractor->first_name}} {{$contractor->last_name}}</td>
                                        <td>{{$contractor->created_at->todatestring()}}</td>
                                        <td>{{$contractor->created_by}}</td>
                                        <td>{{$contractor->phone_no}}</td>
                                        <td>
                                            <div class="row mb-0">
                                              <div class="col">
                                                    {{-- 
                                                        Edit button will navigate us to contractors.edit
                                                        for defining a route you can use route method
                                                        route('route name') or if you want to pass data like
                                                        below then use route('route name',$data)
                                                     --}}
                                                    <a href="{{route('contractors.edit',$contractor->id)}}" class="btn btn-floating btn-small waves=effect waves-light orange"><i class="material-icons">mode_edit</i></a>
                                                </div>
                                                @can('isAdmin')
                                                <div class="col">
                                                    {{-- 
                                                        Delete button will navigate us to contractors.destroy
                                                     --}}
                                                    <form action="{{route('contractors.destroy',$contractor->id)}}" method="POST">
                                                        {{--
                                                            @method('DELETE') is a hidden input that we need
                                                            to make a Delete request because html doesn't support
                                                            DELETE and PUT methods
                                                        --}}
                                                        @method('DELETE')
                                                        {{--
                                                            @csrf() is also a hidden input that renders the csrf token
                                                            for security
                                                        --}}
                                                        @csrf()
                                                        <button type="submit" class="btn btn-floating btn-small waves=effect waves-light red"><i class="material-icons">delete</i></button>
                                                    </form>
                                                </div>
                                                @endcan
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @else
                                {{-- if there are no contractors then show this message --}}
                                <tr>
                                    <td colspan="5"><h6 class="grey-text text-darken-2 center">No Contractors found!</h6></td>
                                </tr>
                            @endif
                            @if(isset($search))
                                <tr>
                                    <td colspan="3">
                                        <a href="/contractors" class="right">Show All</a>
                                    </td>
                                </tr>
                            @endif
                        </tbody>
                    </table>
                    {{-- Contractors Table END --}}
                </div>
                {{-- Show Pagination Links --}}
                <div class="center" id="pagination">
                  {{$contractors->links('vendor.pagination.default',['paginator' => $contractors])}}
                </div>
            </div>
        </div>
        <!-- Card END -->
    </div>
</div>


{{-- This is the button that is located at the bottom right, that navigates us to unit.create view --}}
<div class="fixed-action-btn">
    <a class="btn-floating btn-large waves=effect waves-light red" href="{{route('contractors.create')}}">
        <i class="large material-icons">add</i>
    </a>
</div> 
@endsection