@extends('layouts.app')
@section('content')
<div class="container">
    <h4 class="grey-text text-darken-1 center">Manage Moulding</h4>
    {{-- Search --}}
    <!-- {{-- Include the searh component with with title and route --}}
    @component('sys_mg.inc.search',['title' => 'Loading' , 'route' => 'loadings.search'])
    @endcomponent -->
    <div class="row mb-0">
        <ul class="collapsible">
            <li>
                <div class="collapsible-header">
                    <i class="material-icons">search</i>
                    Search Moulding Details
                </div>
                <div class="collapsible-body">
                    <div class="row mb-0">
                        <form action="{{route('mouldings.search')}}" method="POST">
                            @csrf()
                            <div class="input-field col s12 m6 l5 xl6">
                                <input id="search" type="text" name="search" >
                                <label for="search">Search Moulding Details</label>
                                <span class="{{$errors->has('search') ? 'helper-text red-text' : '' }}">{{$errors->has('search') ? $errors->first('search') : '' }}</span>
                            </div>
                            <div class="input-field col s12 m6 l4 xl4">
                                <select name="options" id="options">
                                    <option value="">Search By</option>
                                    <option value="unit_name">Unit Name</option>
                                    <option value="first_name">Labour Name</option>
                                  
                                    <option value="moulding_at">Moulding Date</option>
                                </select>
                                <label for="options">Search by:</label>
                            </div>
                            <br>
                            <div class="col l2">
                                <button type="submit" class="btn waves-effect waves-light">Search</button>
                            </div>
                        </form>
                    </div>
                </div>
            </li>
        </ul>
    </div>
    {{-- Search END --}}
        <!-- Show All Employee List as a Card -->
    <div class="card">
        <div class="card-content">
            <div class="row">
                <h5 class="pl-15 grey-text text-darken-2">Moulding Details</h5>
                <!-- Table that shows Employee List -->
                <table class="responsive-table col s12 m12 l12 xl12">
                    <thead class="grey-text text-darken-1">
                        <tr>
                            <th>ID</th>
                            <th>Moulding Date</th>
                            <th>Unit Name</th>
                            <th>Labour Name</th>
                            <th>Total Bricks</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody id="moulding-table">
                        <!-- Check if there are any employee to render in view -->
                        @if($mouldings->count())
                            @foreach($mouldings as $moulding)
                                <tr>
                                    <td>{{$moulding->id}}</td>
                                    <td>{{$moulding->moulding_at}}</td>
                                    <td>{{$moulding->jbiUnit->unit_name}}</td>
                                    <td>{{$moulding->jbiLabour->first_name}} {{$moulding->jbiLabour->last_name}}</td>
                                    <td>{{$moulding->no_of_bricks}}</td>
                                    <td>
                                            <div class="row mb-0">
                                              <div class="col">
                                                    {{-- 
                                                        Edit button will navigate us to mouldings.edit
                                                        for defining a route you can use route method
                                                        route('route name') or if you want to pass data like
                                                        below then use route('route name',$data)
                                                     --}}
                                                    <a href="{{route('mouldings.edit',$moulding->id)}}" class="btn btn-floating btn-small waves=effect waves-light orange"><i class="material-icons">mode_edit</i></a>
                                                </div>
                                                @can('isAdmin')
                                                <div class="col">
                                                    {{-- 
                                                        Delete button will navigate us to mouldings.destroy
                                                     --}}
                                                    <form action="{{route('mouldings.destroy',$moulding->id)}}" method="POST">
                                                        {{--
                                                            @method('DELETE') is a hidden input that we need
                                                            to make a Delete request because html doesn't support
                                                            DELETE and PUT methods
                                                        --}}
                                                        @method('DELETE')
                                                        {{--
                                                            @csrf() is also a hidden input that renders the csrf token
                                                            for security
                                                        --}}
                                                        @csrf()
                                                        <button type="submit" class="btn btn-floating btn-small waves=effect waves-light red"><i class="material-icons">delete</i></button>
                                                    </form>
                                                </div>
                                                @endcan
                                            </div>
                                        </td>
                                </tr>
                            @endforeach
                            @if(isset($search))
                                <tr>
                                    <td colspan="4">
                                        <a href="/mouldings" class="right">Show All</a>
                                    </td>
                                </tr>
                            @endif
                        @else
                            {{-- if there are no labours then show this message --}}
                            <tr>
                                <td colspan="5"><h6 class="grey-text text-darken-2 center">No Moulding Details Found!</h6></td>
                            </tr>
                        @endif
                    </tbody>
                </table>
                <!-- employees Table END -->
            </div>
            <!-- Show Pagination Links -->
            <div class="center">
                {{$mouldings->links('vendor.pagination.default',['paginator' => $mouldings])}}
            </div>
        </div>
    </div>
    <!-- Card END -->
</div>
<!-- This is the button that is located at the right bottom, that navigates us to employees.create view -->
<div class="fixed-action-btn">
    <a class="btn-floating btn-large waves=effect waves-light red" href="{{route('mouldings.create')}}">
        <i class="large material-icons">add</i>
    </a>
</div> 
@endsection