@extends('layouts.app')
@section('content')
<div class="container">
    <h4 class="grey-text text-darken-2 center">Role Management</h4>
    
    {{-- Search --}}
    {{-- Include the searh component with with title and route --}}
    @component('sys_mg.inc.search',['title' => 'Role' , 'route' => 'roles.search'])
    @endcomponent
    {{-- Search END --}}
    
    <div class="row">
        <!-- Show All Admins List as a Card -->
        <div class="card col s12 m12 l12 xl12">
            <div class="card-content">
                <div class="row">
                    <h5 class="pl-15 grey-text text-darken-2">Roles List</h5>
                    <!-- Table that shows Admins List -->
                    <table class="responsive-table col s12 m12 l12 xl12">
                        <thead class="grey-text text-darken-2">
                            <tr>
                                <th>Id</th>
                                <th>Role</th>
                                <th>Slug</th>
                                <th>Permissions</th>
                                <th>Options</th>
                            </tr>
                        </thead>
                        <tbody>
                            @if($roles->count())
                                @foreach($roles as $role)
                                    <tr>
                                                <td>{{ $role->id }}</td>
                                                <td>{{ $role->name }}</td>
                                                <td>{{ $role->slug }}</td>
                                                <td>
                                                    @if ($role->permissions != null)
                                                            
                                                        @foreach ($role->permissions as $permission)
                                                        <span class="badge badge-secondary">
                                                            {{ $permission->name }}                                    
                                                        </span>
                                                        @endforeach
                                                    
                                                    @endif
                                                </td>

                                        <td>
                                            <div class="row mb-0">
                                                <div class="col">
                                                    <a href="{{route('roles.edit',$role->id)}}" class="btn btn-floating btn-small waves=effect waves-light orange"><i class="material-icons">mode_edit</i></a>
                                                </div>
                                                <div class="col">
                                                    <form action="{{route('roles.destroy',$role->id)}}" method="POST">
                                                        @method('DELETE')
                                                        @csrf()
                                                        <button type="submit" class="btn btn-floating btn-small waves=effect waves-light red"><i class="material-icons">delete</i></button>
                                                    </form>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                                @else
                                    {{-- if there are no users then show this message --}}
                                    <tr>
                                        <td colspan="5"><h6 class="grey-text text-darken-2 center">No Roles Found!</h6></td>
                                    </tr>
                                @endif
                                {{-- If we are searching then show this link --}}
                                @if(isset($search))
                                    <tr>
                                        <td colspan="4">
                                            <a href="/roles" class="right">Show All</a>
                                        </td>
                                    </tr>
                                @endif
                        </tbody>
                    </table>
                    <!-- Admins Table END -->
                </div>
                <!-- Show Pagination Links -->
                <div class="center">
                  {{$roles->links('vendor.pagination.default',['paginator' => $roles])}}
                </div>
            </div>
        </div>

       
        <!-- Card END -->
    </div>
</div>


<!-- This is the button that is located at the right bottom, that navigates us to admins.create view -->
<div class="fixed-action-btn">
    <a class="btn-floating btn-large waves=effect waves-light red" href="{{route('roles.create')}}">
        <i class="large material-icons">add</i>
    </a>
</div> 

@section('js_role_page')

<script>
    $('#deleteModal').on('show.bs.modal', function (event) {
        var button = $(event.relatedTarget) 
        var role_id = button.data('roleid') 
        
        var modal = $(this)
        // modal.find('.modal-footer #role_id').val(role_id)
        modal.find('form').attr('action','/roles/' + role_id);
    })
</script>

@endsection
@endsection