@extends('layouts.app')
@section('content')
<div class="container">
    <h4 class="grey-text text-darken-1 center">Sales Report</h4>
    {{-- Search --}}
    <div class="row mb-0">
        <ul class="collapsible">
            <li>
                <div class="collapsible-header">
                    <i class="material-icons">search</i>
                    Search Sales report
                </div>
                <div class="collapsible-body">
                    <div class="row mb-0">
                        <form action="{{route('sales.search')}}" method="POST">
                            @csrf()
                            <div class="input-field col s12 m6 l5 xl6">
                                <input id="search" type="text" name="search" >
                                <label for="search">Search Sales report</label>
                                <span class="{{$errors->has('search') ? 'helper-text red-text' : '' }}">{{$errors->has('search') ? $errors->first('search') : '' }}</span>
                            </div>
                            <div class="input-field col s12 m6 l4 xl4">
                                <select name="options" id="options">
                                    <option value="">Search By</option>
                                    <option value="sale_at">Sale At</option>
                                    <option value="unit_name">Unit Name</option>
                                    <option value="first_name">Customer Name</option>
                                  
                                    <option value="bricksclass_name">Bricks Name</option>
                                </select>
                                <label for="options">Search by:</label>
                            </div>
                            <br>
                            <div class="col l2">
                                <button type="submit" class="btn waves-effect waves-light">Search</button>
                            </div>
                        </form>
                    </div>
                </div>
            </li>
        </ul>
    </div>
    {{-- Search END --}}
        <!-- Show All Employee List as a Card -->
    <div class="card">
        <div class="card-content">
            <div class="row">
                <h5 class="pl-15 grey-text text-darken-2">Sales Report</h5>
                <!-- Table that shows Employee List -->
                <table class="responsive-table col s12 m12 l12 xl12">
                    <thead class="grey-text text-darken-1">
                        <tr>
                            <th>ID</th>
                            <th>Sale At</th>
                            <th>Customer Name</th>
                            <th>Unit Name</th>
                            <th>Bricks Name</th>
                            <th>No Of Bricks</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody id="sale-table">
                        <!-- Check if there are any employee to render in view -->
                        @if($sales->count())
                            @foreach($sales as $sale)
                                <tr>
                                    <td>{{$sale->id}}</td>
                                    <td>{{$sale->sale_at}}</td>
                                    <td>{{$sale->empCustomer->first_name}} {{$sale->empCustomer->last_name}}</td>
                                    <td>{{$sale->empUnit->unit_name}}</td>
                                    <td>{{$sale->empBricksclass->bricksclass_name}}</td>
                                    <td>{{$sale->no_of_bricks}}</td>
                                    

                                    <td>
                                            <div class="row mb-0">

                                                <div class="col">
                                                   
                                                   <a href="{{route('sales.show',$sale->id)}}" class="btn btn-small btn-floating waves=effect waves-light teal lighten-2"><i class="material-icons">visibility</i></a>
                                                </div>
                                              <div class="col">
                                                    {{-- 
                                                        Edit button will navigate us to sales.edit
                                                        for defining a route you can use route method
                                                        route('route name') or if you want to pass data like
                                                        below then use route('route name',$data)
                                                     --}}
                                                    <a href="{{route('sales.edit',$sale->id)}}" class="btn btn-floating btn-small waves=effect waves-light orange"><i class="material-icons">mode_edit</i></a>
                                                </div>
                                                @can('isAdmin')
                                                <div class="col">
                                                    {{-- 
                                                        Delete button will navigate us to sales.destroy
                                                     --}}
                                                    <form action="{{route('sales.destroy',$sale->id)}}" method="POST">
                                                        {{--
                                                            @method('DELETE') is a hidden input that we need
                                                            to make a Delete request because html doesn't support
                                                            DELETE and PUT methods
                                                        --}}
                                                        @method('DELETE')
                                                        {{--
                                                            @csrf() is also a hidden input that renders the csrf token
                                                            for security
                                                        --}}
                                                        @csrf()
                                                        <button type="submit" class="btn btn-floating btn-small waves=effect waves-light red"><i class="material-icons">delete</i></button>
                                                    </form>
                                                </div>
                                                @endcan
                                            </div>
                                        </td>
                                </tr>
                            @endforeach
                            @if(isset($search))
                                <tr>
                                    <td colspan="4">
                                        <a href="/sales" class="right">Show All</a>
                                    </td>
                                </tr>
                            @endif
                        @else
                            {{-- if there are no sales then show this message --}}
                            <tr>
                                <td colspan="5"><h6 class="grey-text text-darken-2 center">No Sales Report Found!</h6></td>
                            </tr>
                        @endif
                    </tbody>
                </table>
                
            </div>
            <!-- Show Pagination Links -->
            <div class="center">
                {{$sales->links('vendor.pagination.default',['paginator' => $sales])}}
            </div>
        </div>
        
    <div class="card-action">
                    <a href="/dashboard"class="previous">&laquo; Go To Dashboard</a>
                </div>
    </div>
    </div>
    <!-- Card END -->
</div>
<!-- This is the button that is located at the right bottom, that navigates us to sales.create view -->
<div class="fixed-action-btn">
    <a class="btn-floating btn-large waves=effect waves-light red" href="{{route('sales.create')}}">
        <i class="large material-icons">add</i>
    </a>
</div> 
@endsection