@extends('layouts.app')
@section('content')
<div class="container">
    <h4 class="grey-text text-darken-2 center">Unit List</h4>
    
    {{-- Include the searh component with with title and route --}}
    @component('sys_mg.inc.search',['title' => 'Unit' , 'route' => 'units.search'])
    @endcomponent
    
    <div class="row">
        {{-- Show All Units List as a Card --}}
        <div class="card col s12 m12 l12 xl12">
            <div class="card-content">
                <div class="row">
                    <h5 class="pl-15 grey-text text-darken-2">Unit List</h5>
                    {{-- Table that shows Units List --}}
                    <table class="responsive-table col s12 m12 l12 xl12">
                        <thead class="grey-text text-darken-2">
                            <tr>
                                <th>ID</th>
                                <th>Unit Name</th>
                                <th>No Of Chambers</th>
                                <th>Created at</th>
                                <th>Created by</th>
                                <th>Updated by</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody id="unit-table">
                            {{-- Check if there are any units to render in view --}}
                            @if($units->count())
                                @foreach($units as $unit)
                                    <tr>
                                        <td>{{$unit->id}}</td>
                                        <td>{{$unit->unit_name}}</td>
                                        <td>{{$unit->no_of_chamber}}</td>
                                        <td>{{$unit->created_at->todatestring()}}</td>
                                        <td>{{$unit->created_by}}</td>
                                        <td>{{$unit->updated_by}}</td>
                                        <td>
                                            <div class="row mb-0">
                                              <div class="col">
                                                    {{-- 
                                                        Edit button will navigate us to units.edit
                                                        for defining a route you can use route method
                                                        route('route name') or if you want to pass data like
                                                        below then use route('route name',$data)
                                                     --}}
                                                    <a href="{{route('units.edit',$unit->id)}}" class="btn btn-floating btn-small waves=effect waves-light orange"><i class="material-icons">mode_edit</i></a>
                                                </div>
                                                @can('isAdmin')
                                                <div class="col">
                                                    {{-- 
                                                        Delete button will navigate us to units.destroy
                                                     --}}
                                                    <form action="{{route('units.destroy',$unit->id)}}" method="POST">
                                                        {{--
                                                            @method('DELETE') is a hidden input that we need
                                                            to make a Delete request because html doesn't support
                                                            DELETE and PUT methods
                                                        --}}
                                                        @method('DELETE')
                                                        {{--
                                                            @csrf() is also a hidden input that renders the csrf token
                                                            for security
                                                        --}}
                                                        @csrf()
                                                        <button type="submit" class="btn btn-floating btn-small waves=effect waves-light red"><i class="material-icons">delete</i></button>
                                                    </form>
                                                </div>
                                                @endcan
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @else
                                {{-- if there are no units then show this message --}}
                                <tr>
                                    <td colspan="5"><h6 class="grey-text text-darken-2 center">No Units found!</h6></td>
                                </tr>
                            @endif
                            @if(isset($search))
                                <tr>
                                    <td colspan="3">
                                        <a href="/units" class="right">Show All</a>
                                    </td>
                                </tr>
                            @endif
                        </tbody>
                    </table>
                    {{-- Units Table END --}}
                </div>
                {{-- Show Pagination Links --}}
                <div class="center" id="pagination">
                  {{$units->links('vendor.pagination.default',['paginator' => $units])}}
                </div>
            </div>
            <div class="card-action">
                    <a href="/dashboard"class="previous">&laquo; Go Back</a>
                </div>
        </div>
        <!-- Card END -->
    </div>
</div>


{{-- This is the button that is located at the bottom right, that navigates us to unit.create view --}}
<div class="fixed-action-btn">
    <a class="btn-floating btn-large waves=effect waves-light red" href="{{route('units.create')}}">
        <i class="large material-icons">add</i>
    </a>
</div> 
@endsection